// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package me

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	svr "LAPP_LF_MOM_BACKEND/services/me"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Interface Name           : RegisterRoutes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 注册路由
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterRoutes() {
	// 模块me路由分组
	grmi.RegisterRouteMapping("/me", func(party router.Party) {

		// Project的路由组
		project := party.Party("/project")
		// Project的服务实例
		var serviceOfProject = svr.NewProjectService()
		// Project插入一条
		RegisterInsertOneProject(project, "/insertone", serviceOfProject.InsertOne)
		// Project插入多条
		// RegisterInsertProject(project, "/insert", serviceOfProject.Insert)
		// Project删除一条
		RegisterDeleteOneProject(project, "/deleteone", serviceOfProject.DeleteOne)
		// Project删除多条
		// RegisterDeleteProject(project, "/delete", serviceOfProject.Delete)
		// Project查询多条
		RegisterSelectProject(project, "/query", serviceOfProject.Select)
		// Project查询一条
		RegisterSelectOneProject(project, "/get", serviceOfProject.SelectOne)
		// Project修改一条
		RegisterUpdateOneProject(project, "/updateone", serviceOfProject.UpdateOne)
		// Project修改多条
		// RegisterUpdateProject(project, "/update", serviceOfProject.Update)

		// SetupMatrix的路由组
		setupmatrix := party.Party("/setupmatrix")
		// SetupMatrix的服务实例
		var serviceOfSetupMatrix = svr.NewSetupMatrixService()
		// SetupMatrix插入一条
		RegisterInsertOneSetupMatrix(setupmatrix, "/insertone", serviceOfSetupMatrix.InsertOne)
		// SetupMatrix插入多条
		// RegisterInsertSetupMatrix(setupmatrix, "/insert", serviceOfSetupMatrix.Insert)
		// SetupMatrix删除一条
		RegisterDeleteOneSetupMatrix(setupmatrix, "/deleteone", serviceOfSetupMatrix.DeleteOne)
		// SetupMatrix删除多条
		// RegisterDeleteSetupMatrix(setupmatrix, "/delete", serviceOfSetupMatrix.Delete)
		// SetupMatrix查询多条
		RegisterSelectSetupMatrix(setupmatrix, "/query", serviceOfSetupMatrix.Select)
		// SetupMatrix查询一条
		RegisterSelectOneSetupMatrix(setupmatrix, "/get", serviceOfSetupMatrix.SelectOne)
		// SetupMatrix修改一条
		RegisterUpdateOneSetupMatrix(setupmatrix, "/updateone", serviceOfSetupMatrix.UpdateOne)
		// SetupMatrix修改多条
		// RegisterUpdateSetupMatrix(setupmatrix, "/update", serviceOfSetupMatrix.Update)

		// BomHead的路由组
		bomhead := party.Party("/bomhead")
		// BomHead的服务实例
		var serviceOfBomHead = svr.NewBomHeadService()
		// BomHead插入一条
		RegisterInsertOneBomHead(bomhead, "/insertone", serviceOfBomHead.InsertOne)
		// BomHead插入多条
		// RegisterInsertBomHead(bomhead, "/insert", serviceOfBomHead.Insert)
		// BomHead删除一条
		RegisterDeleteOneBomHead(bomhead, "/deleteone", serviceOfBomHead.DeleteOne)
		// BomHead删除多条
		// RegisterDeleteBomHead(bomhead, "/delete", serviceOfBomHead.Delete)
		// BomHead查询多条
		RegisterSelectBomHead(bomhead, "/query", serviceOfBomHead.Select)
		// BomHead查询一条
		RegisterSelectOneBomHead(bomhead, "/get", serviceOfBomHead.SelectOne)
		// BomHead修改一条
		RegisterUpdateOneBomHead(bomhead, "/updateone", serviceOfBomHead.UpdateOne)
		// BomHead修改多条
		// RegisterUpdateBomHead(bomhead, "/update", serviceOfBomHead.Update)

		// BomLst的路由组
		bomlst := party.Party("/bomlst")
		// BomLst的服务实例
		var serviceOfBomLst = svr.NewBomLstService()
		// BomLst插入一条
		RegisterInsertOneBomLst(bomlst, "/insertone", serviceOfBomLst.InsertOne)
		// BomLst插入多条
		// RegisterInsertBomLst(bomlst, "/insert", serviceOfBomLst.Insert)
		// BomLst删除一条
		RegisterDeleteOneBomLst(bomlst, "/deleteone", serviceOfBomLst.DeleteOne)
		// BomLst删除多条
		// RegisterDeleteBomLst(bomlst, "/delete", serviceOfBomLst.Delete)
		// BomLst查询多条
		RegisterSelectBomLst(bomlst, "/query", serviceOfBomLst.Select)
		// BomLst查询一条
		RegisterSelectOneBomLst(bomlst, "/get", serviceOfBomLst.SelectOne)
		// BomLst修改一条
		RegisterUpdateOneBomLst(bomlst, "/updateone", serviceOfBomLst.UpdateOne)
		// BomLst修改多条
		// RegisterUpdateBomLst(bomlst, "/update", serviceOfBomLst.Update)
	})
}

/******************************************************************************
 *
 * @Interface Name           : init
 *-----------------------------------------------------------------------------
 *
 * @Description              : 包初始化方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func init() {

	// 注册路由
	RegisterRoutes()
}
